@@ -21,11 +21,11 @@ Virani - PCAP retrieval for a FPC setup writing to PCAP files.
 
 =head1 VERSION
 
-Version 0.1.1
+Version 0.2.0
 
 =cut
 
-our $VERSION = '0.1.1';
+our $VERSION = '0.2.0';
 
 =head1 SYNOPSIS
 
@@ -474,7 +474,7 @@ Generates a PCAP locally and returns the path to it.
         - Default :: ''
 
     - set :: The PCAP set to use. Will use what ever the default is set to if undef or blank.
-        - Default :: $viarni->get_default_set
+        - Default :: $virani->get_default_set
 
     - file :: The file to output to. If undef it just returns the path to
               the cache file.
@@ -545,6 +545,7 @@ sub get_pcap_local {
 	if ( !$self->check_type( $opts{type} ) ) {
 		die( 'type "' . $opts{type} . '" is not a supported type, tcpdump or tshark,' );
 	}
+	$self->verbose( 'info', 'Type: ' . $opts{type} );
 
 	# basic sanity checking
 	if ( !defined( $opts{start} ) ) {
@@ -558,18 +559,23 @@ sub get_pcap_local {
 	} elsif ( defined( $opts{padding} ) && $opts{padding} !~ /^\d+/ ) {
 		die('$opts{padding} is not numeric');
 	}
+	$self->verbose( 'info', 'Start: ' . $opts{start}->strftime('%Y-%m-%dT%H:%M:%S%z') . ', ' . $opts{start}->epoch );
+	$self->verbose( 'info', 'End: ' . $opts{end}->strftime('%Y-%m-%dT%H:%M:%S%z') . ', ' . $opts{end}->epoch );
 
 	if ( !defined( $opts{auto_no_cache} ) ) {
 		$opts{auto_no_cache} = 1;
 	}
+	$self->verbose( 'info', 'auto_no_cache: ' . $opts{auto_no_cache} );
 
 	if ( !defined( $opts{no_cache} ) ) {
 		$opts{no_cache} = 0;
 	}
+	$self->verbose( 'info', 'no_cache: ' . $opts{no_cache} );
 
 	if ( !defined( $opts{set} ) || $opts{set} eq '' ) {
 		$opts{set} = $self->get_default_set;
 	}
+	$self->verbose( 'info', 'Set: ' . $opts{set} );
 
 	# make sure the set exists
 	if ( !defined( $self->{sets}->{ $opts{set} } ) ) {
@@ -593,6 +599,7 @@ sub get_pcap_local {
 
 	# clean the filter
 	$opts{filter} = $self->filter_clean( $opts{filter} );
+	$self->verbose( 'info', 'Filter: ' . $opts{filter} );
 
 	# get the cache file to use
 	my $cache_file;
@@ -622,7 +629,7 @@ sub get_pcap_local {
 			$cache_message = $cache_message . ' -> "' . $opts{file} . '"';
 		}
 		$self->verbose( 'info', $cache_message );
-		if ( defined( $opts{file} ) ) {
+		if ( defined( $opts{file} ) && $opts{file} ne $cache_file ) {
 			cp( $cache_file, $opts{file} );
 		}
 		my $to_return;
@@ -645,6 +652,9 @@ sub get_pcap_local {
 	# set the padding
 	my $start = $opts{start} - $opts{padding};
 	my $end   = $opts{end} + $opts{padding};
+	$self->verbose( 'info',
+		'Padded Start: ' . $opts{start}->strftime('%Y-%m-%dT%H:%M:%S%z') . ', ' . $opts{start}->epoch );
+	$self->verbose( 'info', 'Padded End: ' . $opts{end}->strftime('%Y-%m-%dT%H:%M:%S%z') . ', ' . $opts{end}->epoch );
 
 	# get the set
 	my $set_path = $self->get_set_path( $opts{set} );
@@ -692,10 +702,6 @@ sub get_pcap_local {
 		end           => $opts{end}->strftime('%Y-%m-%dT%H:%M:%S%z'),
 	};
 
-	$self->verbose( 'info', 'Filter: ' . $opts{filter} );
-	$self->verbose( 'info', 'Start: ' . $opts{start}->strftime('%Y-%m-%dT%H:%M:%S%z') . ', ' . $opts{start}->epoch );
-	$self->verbose( 'info', 'End: ' . $opts{end}->strftime('%Y-%m-%dT%H:%M:%S%z') . ', ' . $opts{end}->epoch );
-
 	# used for tracking the files to cleanup
 	my @tmp_files;
 
@@ -820,7 +826,7 @@ If no set is given, the default is used.
 
 Will return undef if the set does not exist or if the set does not have a path defined.
 
-    my $path=$viarni->get_set_path($set);
+    my $path=$virani->get_set_path($set);
 
 =cut
 
@@ -865,10 +871,10 @@ sub set_verbose {
 Set if it should be verbose or not.
 
     # send verbose messages to syslog
-    $viarni->set_verbose_to_syslog(1);
+    $virani->set_verbose_to_syslog(1);
 
     # do not send verbose messages to syslog
-    $viarni->set_verbose_to_syslog(0);
+    $virani->set_verbose_to_syslog(0);
 
 =cut
 
@@ -908,7 +914,7 @@ sub verbose {
 
 	if ( $self->{verbose} ) {
 		if ( $self->{verbose_to_syslog} ) {
-			openlog( 'viarni', undef, 'daemon' );
+			openlog( 'virani', undef, 'daemon' );
 			syslog( $level, $string );
 			closelog();
 		} else {
